<?php
	/*
	* 2018 - VEGA Informatique
	*
	* NOTICE OF LICENSE
	*
	* This source file is subject to the Open Software License (OSL 3.0)
	* that is bundled with this package in the file LICENSE.txt.
	* It is also available through the world-wide-web at this URL:
	* http://opensource.org/licenses/osl-3.0.php
	*
	* DISCLAIMER
	*
	* Do not edit or add to this file if you wish to upgrade PolarisLink to newer
	* versions in the future. 
	*
	*  @author VEGA Informatique <contact@vega-info.fr>
	*  @copyright  2018 VEGA Informatique
	*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
	*/

	if (!defined('_PS_VERSION_'))
		exit;	
		
	require_once("PolarisLinkException.php");
	require_once("PolarisLinkSite.php");	
		
	/*
	 * Classe de base pour gérer un cache
	 */
	class PolarisLinkProductRef
	{
        private $Link = null;
        private $_CacheSKU = array();
        private $_CacheEAN = array();        
		
		public function __construct(PolarisLinkSite $link)
		{
            $this->Link = $link;
		}		
                
        /*
            Charge le tableau de référence SKU/EAN pour un produit
        */
		public function loadProduct($id_product)
		{
            $db = Db::getInstance();

            // Reset cache
            $this->_CacheSKU = [];
            $this->_CacheEAN = [];

            // Chargement des SKU
            $suppliers = $this->Link->SupplierID.", ".$this->Link->SupplierBackupID;
                
            $results = $db->executeS(                
                "SELECT s.id_product_attribute, s.product_supplier_reference
						FROM " . _DB_PREFIX_ . "product_supplier AS s
						LEFT JOIN " . _DB_PREFIX_ . "product_attribute AS pa ON (pa.id_product = s.id_product AND pa.id_product_attribute = s.id_product_attribute)
                        WHERE s.id_supplier IN (".$suppliers.") AND s.id_product_attribute <> 0 AND s.id_product = ".$id_product,
                        true, false);
			if ($results === false)
				throw new PrestaShopDatabaseException($db->getMsgError());

            foreach ($results as $result)
            {
                if (!empty($result['product_supplier_reference']))
                    $this->_CacheSKU[(string) $result['product_supplier_reference']] = (int) $result["id_product_attribute"];
            }

            // Chargement des EANs ...
            $results = $db->executeS("SELECT id_product_attribute, ean13, upc FROM "._DB_PREFIX_."product_attribute WHERE ((ean13 IS NOT NULL AND ean13 <> '') OR (upc IS NOT NULL AND upc <> '')) AND id_product = ".$id_product, true, false);
			if ($results === false)
				throw new PrestaShopDatabaseException($db->getMsgError());

            foreach ($results as $result)
            {
                if (!empty($result['ean13']))
                    $this->_CacheEAN[(string) $result['ean13']] = (int) $result["id_product_attribute"];
                if (!empty($result['upc']))
                    $this->_CacheEAN[(string) $result['upc']] = (int) $result["id_product_attribute"];
            }
		}
		
		public function getProductAttributeIdFor($skus, $eans = null)
		{
            if (isset($this->_CacheSKU[$skus]))
                return $this->_CacheSKU[$skus];

            // Pas trouvé ? On essayes SKU par SKU
            foreach (explode(',', $skus) as $sku)
            {
                $sku = trim($sku);
                if (isset($this->_CacheSKU[$sku]))
                {
                    // Trouvé !
                    // On sauve la combinaison pour plus tard
                    $this->_CacheSKU[$skus] = $this->_CacheSKU[$sku];
                    return $this->_CacheSKU[$skus];
                }
            }

            // Toujours pas trouvé ? On essayes par EAN
            if ($eans)
            {
                foreach (explode(',', $eans) as $ean)
                {
                    $ean = trim($ean);
                    if (isset($this->_CacheEAN[$ean]))
                    {
                        // Trouvé !
                        // On sauve la combinaison pour plus tard
                        $this->_CacheSKU[$skus] = $this->_CacheEAN[$ean];
                        return $this->_CacheSKU[$skus];
                    }
                }
            }
			
			// toujours pas trouvé ?
			return NULL;
		}
	} 	
